summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMatt A. Tobin <email@mattatobin.com>2021-12-01 15:49:23 -0500
committerMatt A. Tobin <email@mattatobin.com>2021-12-01 15:49:23 -0500
commit73bef64e1c7c8684de3438a17cc01927f0522d6f (patch)
tree6937be7e55fe8baf5239394ee7ff46620f9960bc
parente17b76b4e19e6086f63fd7df867c39f69e1024d8 (diff)
downloadaura-central-73bef64e1c7c8684de3438a17cc01927f0522d6f.tar.gz
No Issue - Sort the lgpl and gre media libs situation
-rw-r--r--dom/media/platforms/ffmpeg/ffvpx/FFVPXRuntimeLinker.cpp10
-rw-r--r--layout/media/moz.build28
-rw-r--r--layout/moz.build2
-rw-r--r--libs/angle/moz.build4
-rw-r--r--libs/brotli/moz.build2
-rw-r--r--libs/cairo/moz.build2
-rw-r--r--libs/expat/lib/moz.build2
-rw-r--r--libs/graphite2/src/moz.build12
-rw-r--r--libs/harfbuzz/src/moz.build2
-rw-r--r--libs/libaom/moz.build2
-rw-r--r--libs/libav/libavcommon.mozbuild2
-rw-r--r--libs/libcubeb/src/moz.build2
-rw-r--r--libs/libcubeb/tests/moz.build2
-rw-r--r--libs/libjpeg/moz.build2
-rw-r--r--libs/libmkv/moz.build2
-rw-r--r--libs/libnestegg/src/moz.build2
-rw-r--r--libs/libogg/moz.build2
-rw-r--r--libs/libopus/moz.build4
-rw-r--r--libs/libpixman/moz.build2
-rw-r--r--libs/libpng/moz.build2
-rw-r--r--libs/libsoundtouch/src/moz.build2
-rw-r--r--libs/libspeex_resampler/src/moz.build2
-rw-r--r--libs/libtheora/moz.build2
-rw-r--r--libs/libtremor/lib/moz.build2
-rw-r--r--libs/libvorbis/moz.build2
-rw-r--r--libs/libvpx/moz.build2
-rw-r--r--libs/libwebp/dec/moz.build2
-rw-r--r--libs/libwebp/demux/moz.build2
-rw-r--r--libs/libwebp/dsp/moz.build2
-rw-r--r--libs/libwebp/moz.build2
-rw-r--r--libs/libwebp/moz/moz.build2
-rw-r--r--libs/libwebp/utils/moz.build2
-rw-r--r--libs/moz.build3
-rw-r--r--libs/ots/src/moz.build2
-rw-r--r--libs/qcms/moz.build2
-rw-r--r--moz.build2
-rw-r--r--system/evil/moz.build4
-rw-r--r--system/moz.build1
-rw-r--r--system/multmedia/gre/Makefile.in (renamed from layout/media/Makefile.in)0
-rw-r--r--system/multmedia/gre/moz.build19
-rw-r--r--system/multmedia/gre/symbols.def.in (renamed from layout/media/symbols.def.in)2
-rw-r--r--system/multmedia/lgpl/lgplmedia.def (renamed from config/external/lgpllibs/lgpllibs.def)2
-rw-r--r--system/multmedia/lgpl/moz.build (renamed from config/external/lgpllibs/moz.build)11
-rw-r--r--system/multmedia/moz.build (renamed from config/external/moz.build)2
44 files changed, 75 insertions, 87 deletions
diff --git a/layout/media/moz.build b/layout/media/moz.build
deleted file mode 100644
index 74ca1332c..000000000
--- a/layout/media/moz.build
+++ /dev/null
@@ -1,28 +0,0 @@
-# -*- Mode: python; indent-tabs-mode: nil; tab-width: 40 -*-
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
-
-with Files('**'):
- BUG_COMPONENT = ('Core', 'Video/Audio')
-
-if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
- GeckoSharedLibrary('gkmedias', linkage=None)
- USE_LIBS += [
- 'nspr',
- ]
-else:
- # media/webrtc/signaling/test/common.build uses the gkmedias library,
- # expecting at least some of what it contains to be linked, but not libxul,
- # so we need to keep an independent pseudo-library, as well as the OS_LIBS
- # on Windows for them to propagate there.
- Library('gkmedias')
-
-if CONFIG['OS_TARGET'] == 'WINNT':
- DEFFILE = 'symbols.def'
- OS_LIBS += [
- 'usp10',
- 'ole32',
- 'msimg32',
- 'winmm',
- ]
diff --git a/layout/moz.build b/layout/moz.build
index 671c837a5..8b0bbf91e 100644
--- a/layout/moz.build
+++ b/layout/moz.build
@@ -34,7 +34,7 @@ TEST_DIRS += [
'tools/reftest',
]
-DIRS += ['build', 'media']
+DIRS += ['build']
if CONFIG['MOZ_DEBUG']:
TEST_DIRS += ['tools/layout-debug']
diff --git a/libs/angle/moz.build b/libs/angle/moz.build
index f12eb6ca5..b9b12ece6 100644
--- a/libs/angle/moz.build
+++ b/libs/angle/moz.build
@@ -176,11 +176,11 @@ if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
NO_VISIBILITY_FLAGS = True
# This tells ANGLE to build the translator with declspec(dllexport) on Windows
-# which we need to get these symbols exported from gkmedias
+# which we need to get these symbols exported from gremedia
DEFINES['COMPONENT_BUILD'] = True
DEFINES['ANGLE_TRANSLATOR_IMPLEMENTATION'] = True
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
diff --git a/libs/brotli/moz.build b/libs/brotli/moz.build
index b2b87b40a..13138adf7 100644
--- a/libs/brotli/moz.build
+++ b/libs/brotli/moz.build
@@ -39,7 +39,7 @@ CFLAGS += ['-DBROTLI_BUILD_PORTABLE']
Library('brotli')
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
HostProgram('brotli')
diff --git a/libs/cairo/moz.build b/libs/cairo/moz.build
index fbf7dfe7f..a33563c6d 100644
--- a/libs/cairo/moz.build
+++ b/libs/cairo/moz.build
@@ -199,4 +199,4 @@ LOCAL_INCLUDES += ['!src', 'src']
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
diff --git a/libs/expat/lib/moz.build b/libs/expat/lib/moz.build
index 63ed70ca8..2506972c6 100644
--- a/libs/expat/lib/moz.build
+++ b/libs/expat/lib/moz.build
@@ -14,6 +14,6 @@ SOURCES += [
'xmltok.c',
]
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
DEFINES['HAVE_EXPAT_CONFIG_H'] = True
diff --git a/libs/graphite2/src/moz.build b/libs/graphite2/src/moz.build
index ecf396e2b..0f46e300e 100644
--- a/libs/graphite2/src/moz.build
+++ b/libs/graphite2/src/moz.build
@@ -57,18 +57,12 @@ SOURCES += [
'UtfCodec.cpp',
]
-if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
- NO_VISIBILITY_FLAGS = True
- DEFINES['GRAPHITE2_EXPORTING'] = True
-else:
- # tell graphite2 not to export symbols, we'll be linking it directly with
- # thebes
- DEFINES['GRAPHITE2_STATIC'] = True
-
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+NO_VISIBILITY_FLAGS = True
+DEFINES['GRAPHITE2_EXPORTING'] = True
+FINAL_LIBRARY = 'lgplmedia'
DEFINES['PACKAGE_VERSION'] = '"moz"'
DEFINES['PACKAGE_BUGREPORT'] = '"http://bugzilla.mozilla.org/"'
diff --git a/libs/harfbuzz/src/moz.build b/libs/harfbuzz/src/moz.build
index 00abf656c..280fda3e6 100644
--- a/libs/harfbuzz/src/moz.build
+++ b/libs/harfbuzz/src/moz.build
@@ -69,7 +69,7 @@ if 'gtk' in CONFIG['MOZ_WIDGET_TOOLKIT']:
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
DEFINES['PACKAGE_VERSION'] = '"moz"'
DEFINES['PACKAGE_BUGREPORT'] = '"http://bugzilla.mozilla.org/"'
diff --git a/libs/libaom/moz.build b/libs/libaom/moz.build
index 32f8e6c1f..abb72c203 100644
--- a/libs/libaom/moz.build
+++ b/libs/libaom/moz.build
@@ -85,7 +85,7 @@ if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
if CONFIG['CLANG_CL'] or not CONFIG['_MSC_VER']:
for f in SOURCES:
diff --git a/libs/libav/libavcommon.mozbuild b/libs/libav/libavcommon.mozbuild
index b470d6249..93b1fbfc2 100644
--- a/libs/libav/libavcommon.mozbuild
+++ b/libs/libav/libavcommon.mozbuild
@@ -44,4 +44,4 @@ if CONFIG['_MSC_VER'] and not CONFIG['CLANG_CL']:
'-wd4305', # 'initializing' : truncation from '__int64' to 'double'
]
-FINAL_LIBRARY = 'lgpllibs'
+FINAL_LIBRARY = 'lgplmedia'
diff --git a/libs/libcubeb/src/moz.build b/libs/libcubeb/src/moz.build
index 50fffb6ff..8f0635db2 100644
--- a/libs/libcubeb/src/moz.build
+++ b/libs/libcubeb/src/moz.build
@@ -70,7 +70,7 @@ if CONFIG['OS_TARGET'] == 'WINNT':
if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
NO_VISIBILITY_FLAGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
CFLAGS += CONFIG['MOZ_ALSA_CFLAGS']
CFLAGS += CONFIG['MOZ_JACK_CFLAGS']
diff --git a/libs/libcubeb/tests/moz.build b/libs/libcubeb/tests/moz.build
index 2973e5883..1f906e2c8 100644
--- a/libs/libcubeb/tests/moz.build
+++ b/libs/libcubeb/tests/moz.build
@@ -51,7 +51,7 @@ else:
USE_LIBS += [
'cubeb',
]
- # Don't link gkmedias for it introduces dependencies on Android.
+ # Don't link gremedia for it introduces dependencies on Android.
if CONFIG['OS_TARGET'] == 'Android':
USE_LIBS += [
'speex',
diff --git a/libs/libjpeg/moz.build b/libs/libjpeg/moz.build
index 9c6d790ee..e3885b995 100644
--- a/libs/libjpeg/moz.build
+++ b/libs/libjpeg/moz.build
@@ -156,5 +156,5 @@ if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
diff --git a/libs/libmkv/moz.build b/libs/libmkv/moz.build
index 018ca7474..07e61bbbc 100644
--- a/libs/libmkv/moz.build
+++ b/libs/libmkv/moz.build
@@ -23,7 +23,7 @@ SOURCES += [
if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
NO_VISIBILITY_FLAGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
diff --git a/libs/libnestegg/src/moz.build b/libs/libnestegg/src/moz.build
index bf9edcdbc..f08d15d0f 100644
--- a/libs/libnestegg/src/moz.build
+++ b/libs/libnestegg/src/moz.build
@@ -10,7 +10,7 @@ UNIFIED_SOURCES += [
if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
NO_VISIBILITY_FLAGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
diff --git a/libs/libogg/moz.build b/libs/libogg/moz.build
index abc8d0285..948c74ea3 100644
--- a/libs/libogg/moz.build
+++ b/libs/libogg/moz.build
@@ -21,4 +21,4 @@ UNIFIED_SOURCES += [
if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
NO_VISIBILITY_FLAGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
diff --git a/libs/libopus/moz.build b/libs/libopus/moz.build
index 9ef394940..d8939d0fc 100644
--- a/libs/libopus/moz.build
+++ b/libs/libopus/moz.build
@@ -16,13 +16,13 @@ EXPORTS.opus += [
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
DEFINES['OPUS_BUILD'] = True
DEFINES['OPUS_VERSION'] = '"v1.1.3-mozilla"'
DEFINES['USE_ALLOCA'] = True
-# We only need to export symbols if we're built into libgkmedias
+# We only need to export symbols if we're built into libgremedia
# instead of libxul.
if not CONFIG['GKMEDIAS_SHARED_LIBRARY']:
DEFINES['OPUS_EXPORT'] = ''
diff --git a/libs/libpixman/moz.build b/libs/libpixman/moz.build
index 2cdffd8cd..fe548e905 100644
--- a/libs/libpixman/moz.build
+++ b/libs/libpixman/moz.build
@@ -59,7 +59,7 @@ SOURCES += [
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
LOCAL_INCLUDES += ['../cairo/src']
if CONFIG['MOZ_USE_PTHREADS']:
diff --git a/libs/libpng/moz.build b/libs/libpng/moz.build
index ff4b9e9cb..913784c59 100644
--- a/libs/libpng/moz.build
+++ b/libs/libpng/moz.build
@@ -49,7 +49,7 @@ Library('mozpng')
if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
NO_VISIBILITY_FLAGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
diff --git a/libs/libsoundtouch/src/moz.build b/libs/libsoundtouch/src/moz.build
index a4294864f..674ef5110 100644
--- a/libs/libsoundtouch/src/moz.build
+++ b/libs/libsoundtouch/src/moz.build
@@ -44,7 +44,7 @@ else:
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'lgpllibs'
+FINAL_LIBRARY = 'lgplmedia'
# Use abort() instead of exception in SoundTouch.
DEFINES['ST_NO_EXCEPTION_HANDLING'] = 1
diff --git a/libs/libspeex_resampler/src/moz.build b/libs/libspeex_resampler/src/moz.build
index c8c8db653..c8134c2b4 100644
--- a/libs/libspeex_resampler/src/moz.build
+++ b/libs/libspeex_resampler/src/moz.build
@@ -17,7 +17,7 @@ SOURCES += [
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
# We don't compile the full speex codec, only the resampler.
DEFINES['OUTSIDE_SPEEX'] = True
diff --git a/libs/libtheora/moz.build b/libs/libtheora/moz.build
index 8bcdb5fd4..2f1d6f919 100644
--- a/libs/libtheora/moz.build
+++ b/libs/libtheora/moz.build
@@ -15,7 +15,7 @@ EXPORTS.theora += [
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
NO_VISIBILITY_FLAGS = True
diff --git a/libs/libtremor/lib/moz.build b/libs/libtremor/lib/moz.build
index abb48f178..b61b8b368 100644
--- a/libs/libtremor/lib/moz.build
+++ b/libs/libtremor/lib/moz.build
@@ -18,7 +18,7 @@ SOURCES += [
'tremor_window.c',
]
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
if CONFIG['OS_ARCH'] == 'AIX':
DEFINES['alloca'] = '__alloca'
diff --git a/libs/libvorbis/moz.build b/libs/libvorbis/moz.build
index 0bc180909..4d3147e44 100644
--- a/libs/libvorbis/moz.build
+++ b/libs/libvorbis/moz.build
@@ -53,7 +53,7 @@ if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
# Suppress warnings in third-party code.
if CONFIG['GNU_CC']:
diff --git a/libs/libvpx/moz.build b/libs/libvpx/moz.build
index eb24847f6..0149a627b 100644
--- a/libs/libvpx/moz.build
+++ b/libs/libvpx/moz.build
@@ -63,7 +63,7 @@ if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
DEFINES['HAVE_CONFIG_H'] = 'vpx_config.h'
diff --git a/libs/libwebp/dec/moz.build b/libs/libwebp/dec/moz.build
index 1b7905b79..78246111a 100644
--- a/libs/libwebp/dec/moz.build
+++ b/libs/libwebp/dec/moz.build
@@ -19,7 +19,7 @@ SOURCES += [
'webp_dec.c',
]
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
diff --git a/libs/libwebp/demux/moz.build b/libs/libwebp/demux/moz.build
index 75d813699..5422a7a25 100644
--- a/libs/libwebp/demux/moz.build
+++ b/libs/libwebp/demux/moz.build
@@ -10,7 +10,7 @@ SOURCES += [
'demux.c',
]
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
diff --git a/libs/libwebp/dsp/moz.build b/libs/libwebp/dsp/moz.build
index c00d5e140..b8128dc13 100644
--- a/libs/libwebp/dsp/moz.build
+++ b/libs/libwebp/dsp/moz.build
@@ -56,7 +56,7 @@ elif CONFIG['INTEL_ARCHITECTURE']:
SOURCES['yuv_sse2.c'].flags += CONFIG['SSE2_FLAGS']
SOURCES['yuv_sse41.c'].flags += CONFIG['SSE2_FLAGS']
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
diff --git a/libs/libwebp/moz.build b/libs/libwebp/moz.build
index 5450e2b47..9b61aa3df 100644
--- a/libs/libwebp/moz.build
+++ b/libs/libwebp/moz.build
@@ -21,7 +21,7 @@ DIRS += [
'utils',
]
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
diff --git a/libs/libwebp/moz/moz.build b/libs/libwebp/moz/moz.build
index bc0ce997b..80f7b9612 100644
--- a/libs/libwebp/moz/moz.build
+++ b/libs/libwebp/moz/moz.build
@@ -10,7 +10,7 @@ SOURCES += [
'cpu.cpp',
]
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
diff --git a/libs/libwebp/utils/moz.build b/libs/libwebp/utils/moz.build
index 619eaee6d..a9c38f2d9 100644
--- a/libs/libwebp/utils/moz.build
+++ b/libs/libwebp/utils/moz.build
@@ -19,7 +19,7 @@ SOURCES += [
'utils.c',
]
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
diff --git a/libs/moz.build b/libs/moz.build
index d7c120d3e..5f7e29768 100644
--- a/libs/moz.build
+++ b/libs/moz.build
@@ -49,6 +49,9 @@ if CONFIG['MOZ_ENABLE_SKIA']:
if CONFIG['MOZ_FFVPX']:
DIRS += ['ffvpx']
+if CONFIG['MOZ_LIBAV_FFT']:
+ DIRS += ['libav']
+
if not CONFIG['MOZ_SYSTEM_HUNSPELL']:
DIRS += ['hunspell']
diff --git a/libs/ots/src/moz.build b/libs/ots/src/moz.build
index 4a28c71e5..e5a8de68f 100644
--- a/libs/ots/src/moz.build
+++ b/libs/ots/src/moz.build
@@ -62,7 +62,7 @@ if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
# We allow warnings for third-party code that can be updated from upstream.
ALLOW_COMPILER_WARNINGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
DEFINES['PACKAGE_VERSION'] = '"moz"'
DEFINES['PACKAGE_BUGREPORT'] = '"http://bugzilla.mozilla.org/"'
diff --git a/libs/qcms/moz.build b/libs/qcms/moz.build
index 9bcbbe63a..32621977a 100644
--- a/libs/qcms/moz.build
+++ b/libs/qcms/moz.build
@@ -19,7 +19,7 @@ SOURCES += [
if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
NO_VISIBILITY_FLAGS = True
-FINAL_LIBRARY = 'gkmedias'
+FINAL_LIBRARY = 'gremedia'
if CONFIG['GNU_CC']:
CFLAGS += ['-Wno-missing-field-initializers']
diff --git a/moz.build b/moz.build
index 6ee1586b2..139b2bdcc 100644
--- a/moz.build
+++ b/moz.build
@@ -41,7 +41,7 @@ if CONFIG['COMPILE_ENVIRONMENT']:
if not CONFIG['JS_STANDALONE']:
# Hopefully build sqlite before nss
DIRS += ['libs/sqlite3']
- DIRS += ['config/external', 'libs/nss']
+ DIRS += ['libs/nss']
if CONFIG['BUILD_CTYPES']:
DIRS += ['config/external/ffi']
diff --git a/system/evil/moz.build b/system/evil/moz.build
index 9cdb06845..8e5449af0 100644
--- a/system/evil/moz.build
+++ b/system/evil/moz.build
@@ -93,8 +93,8 @@ USE_LIBS += [
]
USE_LIBS += [
- 'gkmedias',
- 'lgpllibs',
+ 'gremedia',
+ 'lgplmedia',
'nspr',
'nss',
'psshparser',
diff --git a/system/moz.build b/system/moz.build
index 17b43af8e..1b007d87f 100644
--- a/system/moz.build
+++ b/system/moz.build
@@ -12,6 +12,7 @@ DIRS += [
'interface',
'intl',
'locales',
+ 'multmedia',
'network',
'security',
'themes',
diff --git a/layout/media/Makefile.in b/system/multmedia/gre/Makefile.in
index 86d9b181d..86d9b181d 100644
--- a/layout/media/Makefile.in
+++ b/system/multmedia/gre/Makefile.in
diff --git a/system/multmedia/gre/moz.build b/system/multmedia/gre/moz.build
new file mode 100644
index 000000000..556ad2f90
--- /dev/null
+++ b/system/multmedia/gre/moz.build
@@ -0,0 +1,19 @@
+# -*- Mode: python; indent-tabs-mode: nil; tab-width: 40 -*-
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this
+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+
+if CONFIG['GKMEDIAS_SHARED_LIBRARY']:
+ GeckoSharedLibrary('gremedia', linkage=None)
+ USE_LIBS += ['nspr']
+else:
+ Library('gremedia')
+
+if CONFIG['OS_TARGET'] == 'WINNT':
+ DEFFILE = 'symbols.def'
+ OS_LIBS += [
+ 'usp10',
+ 'ole32',
+ 'msimg32',
+ 'winmm',
+ ]
diff --git a/layout/media/symbols.def.in b/system/multmedia/gre/symbols.def.in
index d21792746..266cb38aa 100644
--- a/layout/media/symbols.def.in
+++ b/system/multmedia/gre/symbols.def.in
@@ -2,7 +2,7 @@
;+# License, v. 2.0. If a copy of the MPL was not distributed with this
;+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
-LIBRARY gkmedias.dll
+LIBRARY gremedia.dll
EXPORTS
nestegg_destroy
nestegg_duration
diff --git a/config/external/lgpllibs/lgpllibs.def b/system/multmedia/lgpl/lgplmedia.def
index 359d97e71..19ed65f81 100644
--- a/config/external/lgpllibs/lgpllibs.def
+++ b/system/multmedia/lgpl/lgplmedia.def
@@ -2,7 +2,7 @@
; License, v. 2.0. If a copy of the MPL was not distributed with this
; file, You can obtain one at http://mozilla.org/MPL/2.0/.
-LIBRARY lgpllibs.dll
+LIBRARY lgplmedia.dll
EXPORTS
av_rdft_init
diff --git a/config/external/lgpllibs/moz.build b/system/multmedia/lgpl/moz.build
index 9900beac9..919ba58f4 100644
--- a/config/external/lgpllibs/moz.build
+++ b/system/multmedia/lgpl/moz.build
@@ -3,15 +3,14 @@
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
-# The lgpllibs library stores symbols from third-party LGPL licensed libraries,
+# The lgplmedia library stores symbols from third-party LGPL licensed libraries,
# such as libav and libsoundtouch. It fulfills the requirement of dynamically
-# linking these symbols into gecko.
+# linking these symbols into gre.
#
# Any library added here should also be reflected in the about:license page.
-GeckoSharedLibrary('lgpllibs', linkage=None)
-SHARED_LIBRARY_NAME = 'lgpllibs'
+GeckoSharedLibrary('lgplmedia', linkage=None)
+SHARED_LIBRARY_NAME = 'lgplmedia'
if CONFIG['MOZ_LIBAV_FFT']:
- DIRS += ['/libs/libav']
- DEFFILE = SRCDIR + '/lgpllibs.def'
+ DEFFILE = SRCDIR + '/lgplmedia.def'
diff --git a/config/external/moz.build b/system/multmedia/moz.build
index 097f80dde..81fdbb4df 100644
--- a/config/external/moz.build
+++ b/system/multmedia/moz.build
@@ -3,4 +3,4 @@
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
-DIRS += ['lgpllibs']
+DIRS += ['gre', 'lgpl']
diff --git a/dom/media/platforms/ffmpeg/ffvpx/FFVPXRuntimeLinker.cpp b/dom/media/platforms/ffmpeg/ffvpx/FFVPXRuntimeLinker.cpp
index 20b1140cb..02be71e4d 100644
--- a/dom/media/platforms/ffmpeg/ffvpx/FFVPXRuntimeLinker.cpp
+++ b/dom/media/platforms/ffmpeg/ffvpx/FFVPXRuntimeLinker.cpp
@@ -51,15 +51,15 @@ FFVPXRuntimeLinker::Init()
sLinkStatus = LinkStatus_FAILED;
- // We retrieve the path of the lgpllibs library as this is where ffvpx* libs are located.
- char* lgpllibsname = PR_GetLibraryName(nullptr, "lgpllibs");
- if (!lgpllibsname) {
+ // We retrieve the path of the lgplmedia library as this is where ffvpx* libs are located.
+ char* lgplmedianame = PR_GetLibraryName(nullptr, "lgplmedia");
+ if (!lgplmedianame) {
return false;
}
char* path =
- PR_GetLibraryFilePathname(lgpllibsname,
+ PR_GetLibraryFilePathname(lgplmedianame,
(PRFuncPtr)&soundtouch::SoundTouch::getVersionId);
- PR_FreeLibraryName(lgpllibsname);
+ PR_FreeLibraryName(lgplmedianame);
if (!path) {
return false;
}